@@ -5,7 +5,7 @@ use warnings;
 package Sub::HandlesVia::HandlerLibrary::Array;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.050002';
+our $VERSION   = '0.050004';
 
 use Exporter::Tiny;
 use Sub::HandlesVia::HandlerLibrary;
@@ -53,7 +53,7 @@ our @METHODS = qw( count is_empty all elements flatten get pop push shift
 	shallow_clone map grep sort reverse sort_in_place splice shuffle
 	shuffle_in_place uniq uniq_in_place delete insert flatten flatten_deep
 	join print head tail apply pick_random for_each for_each_pair
-	all_true not_all_true min minstr max maxstr sum product
+	all_true not_all_true min minstr max maxstr sum product indexed
 	reductions sample uniqnum uniqnum_in_place uniqstr uniqstr_in_place
 	pairs pairkeys pairvalues pairgrep pairfirst pairmap reset );
 
@@ -845,8 +845,8 @@ sub for_each {
 		args      => 1,
 		signature => [CodeRef],
 		usage     => '$coderef',
-		template  => 'foreach my $shv_index (0 .. $#{$GET}) { &{$ARG}(($GET)->[$shv_index], $shv_index) }; $SELF',
-		documentation => 'Chainable method which executes the coderef on each element of the array. The coderef will be passed two values: the element and its index.',
+		template  => 'local $_; foreach my $shv_index (0 .. $#{$GET}) { &{$ARG}($_ = ($GET)->[$shv_index], $shv_index) }; $SELF',
+		documentation => 'Chainable method which executes the coderef on each element of the array. The coderef will be passed two values: the element and its index. The element will also be available as C<< $_ >>.',
 		_examples => sub {
 			my ( $class, $attr, $method ) = @_;
 			return CORE::join "",
@@ -1041,4 +1041,12 @@ sub reset {
 		},
 }
 
+sub indexed {
+	handler
+		name      => 'Array:indexed',
+		args      => 0,
+		template  => 'my $shv_ix = 0; map +($shv_ix++, $_), @{$GET}',
+		documentation => 'Like C<indexed> from L<builtin>.',
+}
+
 1;
